""" Custom Jinja2 filters """
import os

from jinja2 import is_undefined
import socket
from urllib.parse import urlparse

def ip_for_name(value):
    """Resolves the domain name to an IP address
    """
    return socket.gethostbyname(value)


def parse_url(value,ret=None):
    """Parses a url as per urllib.part.urlparse
    """
    if not ret:
        return urlparse(value)
    else:
        return getattr(urlparse(value),ret)


def env(varname, default=None):
    """ Use an environment variable's value inside your template.

        This filter is available even when your data source is something other that the environment.

        Example:

        ```jinja2
        User: {{ user_login }}
        Pass: {{ "USER_PASSWORD"|env }}
        ```

        You can provide the default value:

        ```jinja2
        Pass: {{ "USER_PASSWORD"|env("-none-") }}
        ```

        For your convenience, it's also available as a function:

        ```jinja2
        User: {{ user_login }}
        Pass: {{ env("USER_PASSWORD") }}
        ```

        Notice that there must be quotes around the environment variable name
    """
    if default is not None:
        # With the default, there's never an error
        return os.getenv(varname, default)
    else:
        # Raise KeyError when not provided
        return os.environ[varname]
